<?php
function _deleteUser(&$tof,$vars) {
	require_once("actions/user.php");
	deleteUser(
		$tof,
		$vars['UserID'],
		$vars['RemovePictures'],
		$vars['DeleteFiles']);
}
?>